/*-------------------------------------------------------------------------
 |                                                                         
 |             SAS SUPPLEMENTAL SYNTAX FILE FOR ICPSR 03401
 |         SUBSTANCE ABUSE TREATMENT COST ALLOCATION AND ANALYSIS
 |                  TEMPLATE (SATCAAT) STUDY, 1992-1994
 |               (DATASET 0002: SDU COST DATA -- ALL SDUS)
 |
 | This SAS program is provided for optional use with the SAS transport
 | version of this data file as distributed by ICPSR. The metadata
 | provided below are not stored in the SAS transport version of this data
 | collection.  Users need to use SAS PROC CIMPORT to import the SAS
 | transport file to a SAS data set on their system. This program can
 | then be used in conjunction with the SAS system data file.
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions.  Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set. Users
 | should replace "SAS-dataset" with their name for the SAS data set copied
 | from the SAS transport file. Users can add a SAS libname statement
 | and an output SAS data set name to make a permanent SAS data set.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .;
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables stored in the SAS data set. Users can refer to their
 | SAS manual for information on how to permanently store formats in a
 | SAS catalog.
 |
 | NOTE:  Users should modify this file to suit their specific needs.
 | The MISSING VALUE RECODES section has been commented out (i.e., '/*').
 | To make this section active in the program, users should remove the SAS
 | comment indicators from this section.
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

PROC FORMAT;
  VALUE sdunum    -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE provider  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE sdufocus  -8='(-8) INAPPLICABLE' 1='(1) AFTERCARE' 2='(2) CHILDREN' 3='(3) DETOX'
                  4='(4) HIV' 5='(5) OUTPATIENT' 6='(6) RESIDENTIAL' 7='(7) WOMEN' ;
  VALUE sdutype   -9='(-9) BLANK' -8='(-8) INAPPLICABLE'
                  1='(1) TRANSITIONAL LIVING AFTERCARE' 2='(2) AFTERCARE-WOMEN ONLY'
                  3='(3) OUTPATIENT-AFTERCARE (ADOLESCENT)'
                  4='(4) OUTPATIENT-AFTERCARE (ADULT)'
                  5='(5) RESIDENTIAL PPW-CHILDREN ONLY'
                  6='(6) RESIDENTIAL WOMEN & CHILDREN-CHILDREN ONLY'
                  7='(7) RESIDENTIAL-ADOLESCENT'
                  8='(8) RESIDENTIAL LONG TERM PPW-CHILDREN ONLY'
                  9='(9) RESIDENTIAL SHORT TERM PPW-CHILDREN ONLY'
                  10='(10) RESIDENTIAL-DETOXIFICATION (ADULT)'
                  11='(11) HIV/AIDS OUTREACH' 12='(12) HIV-AIDS OUTREACH-INTENSIVE'
                  13='(13) HIV OUTPATIENT PREVENTION AND COUNSELING'
                  14='(14) HIV OUTREACH AND PRETREATMENT'
                  15='(15) INTENSIVE OUTPATIENT' 16='(16) METHADONE' 17='(17) OUTPATIENT'
                  18='(18) PARTIAL HOSPITAL' 19='(19) OUTPATIENT-ADOLESCENT'
                  20='(20) OUTPATIENT-ADULT' 21='(21) OUTPATIENT-WOMEN'
                  22='(22) RESIDENTIAL-ADULT' 23='(23) RESIDENTIAL PPW-WOMEN ONLY'
                  24='(24) RESIDENTIAL WOMEN & CHILDREN-WOMEN ONLY'
                  25='(25) CENTRAL INTAKE PPW-WOMEN'
                  26='(26) RESIDENTIAL LONG TERM PPW-WOMEN ONLY'
                  27='(27) RESIDENTIAL SHORT TERM PPW-WOMEN ONLY' ;
  VALUE fyend     -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE numclnt   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totcost   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totaft    -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totcnet   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totch     -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totcled   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE tottran   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE tothiv    -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE tothm     -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE tothous   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totiass   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totmds    -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totmes    -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totmhgc   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totmhic   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totpevl   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totpse    -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totrmgt   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totsagc   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totsaic   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totsted   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unaft1ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unaft3ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unaft7ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unaft10f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unaft12f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet4f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet7f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet9f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet0f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet2f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet5f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unch5fff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncled7f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE untran1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE untran2f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE untran3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE untran7f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE untran8f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhiv7ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhiv22f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhiv23f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhiv28f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhm16ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhm18ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhm19ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhous1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uniass2f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uniass3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmds4ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmds7ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmds24f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmds25f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmds26f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmds31f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmes15f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmes16f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmes31f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmhgc8f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmhgc1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmhic8f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmhic1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unpev7ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unpse13f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unpse14f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unpse15f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unpse16f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unpse31f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unrmgt4f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unrmgt7f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unrmgt3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsagc8f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsagc1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsagc2f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsagc3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsaic8f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsaic1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsaic2f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsaic3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsted7f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsted1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsted0f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsted3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE ucaft1ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucaft3ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucaft7ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucaft10f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucaft12f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet4f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet7f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet9f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet0f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet2f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet3f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet5f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucch5fff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccled7f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uctran7f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uctran8f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uctran1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uctran2f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uctran3f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uchiv22f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uchiv23f  -9.0='(-9.0) BLANK' -8.0='(-8.0) INAPPLICABLE' ;
  VALUE uchiv28f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uchiv7ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uchm16ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uchm18ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uchm19ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uchous1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uciass2f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uciass3f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmds4ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmds7ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmds24f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmds25f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmds26f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmds31f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmes15f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmes16f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmes31f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmhgc1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmhic1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucpev7ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucpse13f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucpse14f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucpse15f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucpse16f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucpse31f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucrmgt4f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucrmgt7f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucrmgt3f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsagc8f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsagc1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsagc2f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsagc3f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsaic8f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsaic1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsaic2f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsaic3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE ucsted7f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsted1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsted0f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsted3f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE cstprcl   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgaft    -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgcnet   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgch     -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgcled   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgtran   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avghiv    -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avghm     -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avghous   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgiass   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgmds    -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgmes    -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgmhgc   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgmhic   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgpevl   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgpse    -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgrmgt   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgsagc   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgsaic   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgsted   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
RUN;

* SAS DATA STEP;
DATA;
SET SAS-dataset ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CASEID <= -1) THEN CASEID = .;
   IF (SDUNUM <= -1) THEN SDUNUM = .;
   IF (PROVIDER <= -1) THEN PROVIDER = .;
   IF (SDUFOCUS <= -1) THEN SDUFOCUS = .;
   IF (SDUTYPE <= -1) THEN SDUTYPE = .;
   IF (FYEND <= -1) THEN FYEND = .;
   IF (NUMCLNT <= -1) THEN NUMCLNT = .;
   IF (TOTCOST <= -1) THEN TOTCOST = .;
   IF (TOTAFT <= -1) THEN TOTAFT = .;
   IF (TOTCNET <= -1) THEN TOTCNET = .;
   IF (TOTCH <= -1) THEN TOTCH = .;
   IF (TOTCLED <= -1) THEN TOTCLED = .;
   IF (TOTTRAN <= -1) THEN TOTTRAN = .;
   IF (TOTHIV <= -1) THEN TOTHIV = .;
   IF (TOTHM <= -1) THEN TOTHM = .;
   IF (TOTHOUS <= -1) THEN TOTHOUS = .;
   IF (TOTIASS <= -1) THEN TOTIASS = .;
   IF (TOTMDS <= -1) THEN TOTMDS = .;
   IF (TOTMES <= -1) THEN TOTMES = .;
   IF (TOTMHGC <= -1) THEN TOTMHGC = .;
   IF (TOTMHIC <= -1) THEN TOTMHIC = .;
   IF (TOTPEVL <= -1) THEN TOTPEVL = .;
   IF (TOTPSE <= -1) THEN TOTPSE = .;
   IF (TOTRMGT <= -1) THEN TOTRMGT = .;
   IF (TOTSAGC <= -1) THEN TOTSAGC = .;
   IF (TOTSAIC <= -1) THEN TOTSAIC = .;
   IF (TOTSTED <= -1) THEN TOTSTED = .;
   IF (UNAFT1 <= -1) THEN UNAFT1 = .;
   IF (UNAFT3 <= -1) THEN UNAFT3 = .;
   IF (UNAFT7 <= -1) THEN UNAFT7 = .;
   IF (UNAFT10 <= -1) THEN UNAFT10 = .;
   IF (UNAFT12 <= -1) THEN UNAFT12 = .;
   IF (UNCNET4 <= -1) THEN UNCNET4 = .;
   IF (UNCNET7 <= -1) THEN UNCNET7 = .;
   IF (UNCNET9 <= -1) THEN UNCNET9 = .;
   IF (UNCNET10 <= -1) THEN UNCNET10 = .;
   IF (UNCNET16 <= -1) THEN UNCNET16 = .;
   IF (UNCNET20 <= -1) THEN UNCNET20 = .;
   IF (UNCNET21 <= -1) THEN UNCNET21 = .;
   IF (UNCNET31 <= -1) THEN UNCNET31 = .;
   IF (UNCH5 <= -1) THEN UNCH5 = .;
   IF (UNCLED7 <= -1) THEN UNCLED7 = .;
   IF (UNTRAN16 <= -1) THEN UNTRAN16 = .;
   IF (UNTRAN29 <= -1) THEN UNTRAN29 = .;
   IF (UNTRAN31 <= -1) THEN UNTRAN31 = .;
   IF (UNTRAN7 <= -1) THEN UNTRAN7 = .;
   IF (UNTRAN8 <= -1) THEN UNTRAN8 = .;
   IF (UNHIV7 <= -1) THEN UNHIV7 = .;
   IF (UNHIV22 <= -1) THEN UNHIV22 = .;
   IF (UNHIV23 <= -1) THEN UNHIV23 = .;
   IF (UNHIV28 <= -1) THEN UNHIV28 = .;
   IF (UNHM16 <= -1) THEN UNHM16 = .;
   IF (UNHM18 <= -1) THEN UNHM18 = .;
   IF (UNHM19 <= -1) THEN UNHM19 = .;
   IF (UNHOUS18 <= -1) THEN UNHOUS18 = .;
   IF (UNIASS2 <= -1) THEN UNIASS2 = .;
   IF (UNIASS31 <= -1) THEN UNIASS31 = .;
   IF (UNMDS4 <= -1) THEN UNMDS4 = .;
   IF (UNMDS7 <= -1) THEN UNMDS7 = .;
   IF (UNMDS24 <= -1) THEN UNMDS24 = .;
   IF (UNMDS25 <= -1) THEN UNMDS25 = .;
   IF (UNMDS26 <= -1) THEN UNMDS26 = .;
   IF (UNMDS31 <= -1) THEN UNMDS31 = .;
   IF (UNMES15 <= -1) THEN UNMES15 = .;
   IF (UNMES16 <= -1) THEN UNMES16 = .;
   IF (UNMES31 <= -1) THEN UNMES31 = .;
   IF (UNMHGC8 <= -1) THEN UNMHGC8 = .;
   IF (UNMHGC11 <= -1) THEN UNMHGC11 = .;
   IF (UNMHIC8 <= -1) THEN UNMHIC8 = .;
   IF (UNMHIC11 <= -1) THEN UNMHIC11 = .;
   IF (UNPEV7 <= -1) THEN UNPEV7 = .;
   IF (UNPSE13 <= -1) THEN UNPSE13 = .;
   IF (UNPSE14 <= -1) THEN UNPSE14 = .;
   IF (UNPSE15 <= -1) THEN UNPSE15 = .;
   IF (UNPSE16 <= -1) THEN UNPSE16 = .;
   IF (UNPSE31 <= -1) THEN UNPSE31 = .;
   IF (UNRMGT4 <= -1) THEN UNRMGT4 = .;
   IF (UNRMGT7 <= -1) THEN UNRMGT7 = .;
   IF (UNRMGT31 <= -1) THEN UNRMGT31 = .;
   IF (UNSAGC8 <= -1) THEN UNSAGC8 = .;
   IF (UNSAGC11 <= -1) THEN UNSAGC11 = .;
   IF (UNSAGC27 <= -1) THEN UNSAGC27 = .;
   IF (UNSAGC31 <= -1) THEN UNSAGC31 = .;
   IF (UNSAIC8 <= -1) THEN UNSAIC8 = .;
   IF (UNSAIC11 <= -1) THEN UNSAIC11 = .;
   IF (UNSAIC27 <= -1) THEN UNSAIC27 = .;
   IF (UNSAIC31 <= -1) THEN UNSAIC31 = .;
   IF (UNSTED7 <= -1) THEN UNSTED7 = .;
   IF (UNSTED16 <= -1) THEN UNSTED16 = .;
   IF (UNSTED17 <= -1) THEN UNSTED17 = .;
   IF (UNSTED31 <= -1) THEN UNSTED31 = .;
   IF (UCAFT1 <= -1.00) THEN UCAFT1 = .;
   IF (UCAFT3 <= -1.00) THEN UCAFT3 = .;
   IF (UCAFT7 <= -1.00) THEN UCAFT7 = .;
   IF (UCAFT10 <= -1.00) THEN UCAFT10 = .;
   IF (UCAFT12 <= -1.00) THEN UCAFT12 = .;
   IF (UCCNET4 <= -1.00) THEN UCCNET4 = .;
   IF (UCCNET7 <= -1.00) THEN UCCNET7 = .;
   IF (UCCNET9 <= -1.00) THEN UCCNET9 = .;
   IF (UCCNET10 <= -1.00) THEN UCCNET10 = .;
   IF (UCCNET16 <= -1.00) THEN UCCNET16 = .;
   IF (UCCNET20 <= -1.00) THEN UCCNET20 = .;
   IF (UCCNET21 <= -1.00) THEN UCCNET21 = .;
   IF (UCCNET31 <= -1.00) THEN UCCNET31 = .;
   IF (UCCH5 <= -1.00) THEN UCCH5 = .;
   IF (UCCLED7 <= -1.00) THEN UCCLED7 = .;
   IF (UCTRAN7 <= -1.00) THEN UCTRAN7 = .;
   IF (UCTRAN8 <= -1.00) THEN UCTRAN8 = .;
   IF (UCTRAN16 <= -1.00) THEN UCTRAN16 = .;
   IF (UCTRAN29 <= -1.00) THEN UCTRAN29 = .;
   IF (UCTRAN31 <= -1.00) THEN UCTRAN31 = .;
   IF (UCHIV22 <= -1.00) THEN UCHIV22 = .;
   IF (UCHIV23 <= -1.0) THEN UCHIV23 = .;
   IF (UCHIV28 <= -1.00) THEN UCHIV28 = .;
   IF (UCHIV7 <= -1.00) THEN UCHIV7 = .;
   IF (UCHM16 <= -1) THEN UCHM16 = .;
   IF (UCHM18 <= -1.00) THEN UCHM18 = .;
   IF (UCHM19 <= -1.00) THEN UCHM19 = .;
   IF (UCHOUS18 <= -1.00) THEN UCHOUS18 = .;
   IF (UCIASS2 <= -1.00) THEN UCIASS2 = .;
   IF (UCIASS31 <= -1.00) THEN UCIASS31 = .;
   IF (UCMDS4 <= -1.00) THEN UCMDS4 = .;
   IF (UCMDS7 <= -1.00) THEN UCMDS7 = .;
   IF (UCMDS24 <= -1.00) THEN UCMDS24 = .;
   IF (UCMDS25 <= -1.00) THEN UCMDS25 = .;
   IF (UCMDS26 <= -1.00) THEN UCMDS26 = .;
   IF (UCMDS31 <= -1.00) THEN UCMDS31 = .;
   IF (UCMES15 <= -1.00) THEN UCMES15 = .;
   IF (UCMES16 <= -1.00) THEN UCMES16 = .;
   IF (UCMES31 <= -1.00) THEN UCMES31 = .;
   IF (UCMHGC11 <= -1.00) THEN UCMHGC11 = .;
   IF (UCMHIC11 <= -1.00) THEN UCMHIC11 = .;
   IF (UCPEV7 <= -1.00) THEN UCPEV7 = .;
   IF (UCPSE13 <= -1.00) THEN UCPSE13 = .;
   IF (UCPSE14 <= -1.00) THEN UCPSE14 = .;
   IF (UCPSE15 <= -1.00) THEN UCPSE15 = .;
   IF (UCPSE16 <= -1.00) THEN UCPSE16 = .;
   IF (UCPSE31 <= -1.00) THEN UCPSE31 = .;
   IF (UCRMGT4 <= -1.00) THEN UCRMGT4 = .;
   IF (UCRMGT7 <= -1.00) THEN UCRMGT7 = .;
   IF (UCRMGT31 <= -1.00) THEN UCRMGT31 = .;
   IF (UCSAGC8 <= -1.00) THEN UCSAGC8 = .;
   IF (UCSAGC11 <= -1.00) THEN UCSAGC11 = .;
   IF (UCSAGC27 <= -1.00) THEN UCSAGC27 = .;
   IF (UCSAGC31 <= -1.00) THEN UCSAGC31 = .;
   IF (UCSAIC8 <= -1.00) THEN UCSAIC8 = .;
   IF (UCSAIC11 <= -1.00) THEN UCSAIC11 = .;
   IF (UCSAIC27 <= -1.00) THEN UCSAIC27 = .;
   IF (UCSAIC31 <= -1) THEN UCSAIC31 = .;
   IF (UCSTED7 <= -1.00) THEN UCSTED7 = .;
   IF (UCSTED16 <= -1.00) THEN UCSTED16 = .;
   IF (UCSTED17 <= -1.00) THEN UCSTED17 = .;
   IF (UCSTED31 <= -1.00) THEN UCSTED31 = .;
   IF (CSTPRCL <= -1.00) THEN CSTPRCL = .;
   IF (AVGAFT <= -1.00) THEN AVGAFT = .;
   IF (AVGCNET <= -1.00) THEN AVGCNET = .;
   IF (AVGCH <= -1.00) THEN AVGCH = .;
   IF (AVGCLED <= -1.00) THEN AVGCLED = .;
   IF (AVGTRAN <= -1.00) THEN AVGTRAN = .;
   IF (AVGHIV <= -1.00) THEN AVGHIV = .;
   IF (AVGHM <= -1.00) THEN AVGHM = .;
   IF (AVGHOUS <= -1.00) THEN AVGHOUS = .;
   IF (AVGIASS <= -1.00) THEN AVGIASS = .;
   IF (AVGMDS <= -1.00) THEN AVGMDS = .;
   IF (AVGMES <= -1.00) THEN AVGMES = .;
   IF (AVGMHGC <= -1.00) THEN AVGMHGC = .;
   IF (AVGMHIC <= -1.00) THEN AVGMHIC = .;
   IF (AVGPEVL <= -1.00) THEN AVGPEVL = .;
   IF (AVGPSE <= -1.00) THEN AVGPSE = .;
   IF (AVGRMGT <= -1.00) THEN AVGRMGT = .;
   IF (AVGSAGC <= -1.00) THEN AVGSAGC = .;
   IF (AVGSAIC <= -1.00) THEN AVGSAIC = .;
   IF (AVGSTED <= -1.00) THEN AVGSTED = .;
*/

* SAS FORMAT STATEMENT;

  FORMAT SDUNUM sdunum. PROVIDER provider. SDUFOCUS sdufocus.
         SDUTYPE sdutype. FYEND fyend. NUMCLNT numclnt.
         TOTCOST totcost. TOTAFT totaft. TOTCNET totcnet.
         TOTCH totch. TOTCLED totcled. TOTTRAN tottran.
         TOTHIV tothiv. TOTHM tothm. TOTHOUS tothous.
         TOTIASS totiass. TOTMDS totmds. TOTMES totmes.
         TOTMHGC totmhgc. TOTMHIC totmhic. TOTPEVL totpevl.
         TOTPSE totpse. TOTRMGT totrmgt. TOTSAGC totsagc.
         TOTSAIC totsaic. TOTSTED totsted. UNAFT1 unaft1ff.
         UNAFT3 unaft3ff. UNAFT7 unaft7ff. UNAFT10 unaft10f.
         UNAFT12 unaft12f. UNCNET4 uncnet4f. UNCNET7 uncnet7f.
         UNCNET9 uncnet9f. UNCNET10 uncnet1f. UNCNET16 uncnet0f.
         UNCNET20 uncnet2f. UNCNET21 uncnet3f. UNCNET31 uncnet5f.
         UNCH5 unch5fff. UNCLED7 uncled7f. UNTRAN16 untran1f.
         UNTRAN29 untran2f. UNTRAN31 untran3f. UNTRAN7 untran7f.
         UNTRAN8 untran8f. UNHIV7 unhiv7ff. UNHIV22 unhiv22f.
         UNHIV23 unhiv23f. UNHIV28 unhiv28f. UNHM16 unhm16ff.
         UNHM18 unhm18ff. UNHM19 unhm19ff. UNHOUS18 unhous1f.
         UNIASS2 uniass2f. UNIASS31 uniass3f. UNMDS4 unmds4ff.
         UNMDS7 unmds7ff. UNMDS24 unmds24f. UNMDS25 unmds25f.
         UNMDS26 unmds26f. UNMDS31 unmds31f. UNMES15 unmes15f.
         UNMES16 unmes16f. UNMES31 unmes31f. UNMHGC8 unmhgc8f.
         UNMHGC11 unmhgc1f. UNMHIC8 unmhic8f. UNMHIC11 unmhic1f.
         UNPEV7 unpev7ff. UNPSE13 unpse13f. UNPSE14 unpse14f.
         UNPSE15 unpse15f. UNPSE16 unpse16f. UNPSE31 unpse31f.
         UNRMGT4 unrmgt4f. UNRMGT7 unrmgt7f. UNRMGT31 unrmgt3f.
         UNSAGC8 unsagc8f. UNSAGC11 unsagc1f. UNSAGC27 unsagc2f.
         UNSAGC31 unsagc3f. UNSAIC8 unsaic8f. UNSAIC11 unsaic1f.
         UNSAIC27 unsaic2f. UNSAIC31 unsaic3f. UNSTED7 unsted7f.
         UNSTED16 unsted1f. UNSTED17 unsted0f. UNSTED31 unsted3f.
         UCAFT1 ucaft1ff. UCAFT3 ucaft3ff. UCAFT7 ucaft7ff.
         UCAFT10 ucaft10f. UCAFT12 ucaft12f. UCCNET4 uccnet4f.
         UCCNET7 uccnet7f. UCCNET9 uccnet9f. UCCNET10 uccnet1f.
         UCCNET16 uccnet0f. UCCNET20 uccnet2f. UCCNET21 uccnet3f.
         UCCNET31 uccnet5f. UCCH5 ucch5fff. UCCLED7 uccled7f.
         UCTRAN7 uctran7f. UCTRAN8 uctran8f. UCTRAN16 uctran1f.
         UCTRAN29 uctran2f. UCTRAN31 uctran3f. UCHIV22 uchiv22f.
         UCHIV23 uchiv23f. UCHIV28 uchiv28f. UCHIV7 uchiv7ff.
         UCHM16 uchm16ff. UCHM18 uchm18ff. UCHM19 uchm19ff.
         UCHOUS18 uchous1f. UCIASS2 uciass2f. UCIASS31 uciass3f.
         UCMDS4 ucmds4ff. UCMDS7 ucmds7ff. UCMDS24 ucmds24f.
         UCMDS25 ucmds25f. UCMDS26 ucmds26f. UCMDS31 ucmds31f.
         UCMES15 ucmes15f. UCMES16 ucmes16f. UCMES31 ucmes31f.
         UCMHGC11 ucmhgc1f. UCMHIC11 ucmhic1f. UCPEV7 ucpev7ff.
         UCPSE13 ucpse13f. UCPSE14 ucpse14f. UCPSE15 ucpse15f.
         UCPSE16 ucpse16f. UCPSE31 ucpse31f. UCRMGT4 ucrmgt4f.
         UCRMGT7 ucrmgt7f. UCRMGT31 ucrmgt3f. UCSAGC8 ucsagc8f.
         UCSAGC11 ucsagc1f. UCSAGC27 ucsagc2f. UCSAGC31 ucsagc3f.
         UCSAIC8 ucsaic8f. UCSAIC11 ucsaic1f. UCSAIC27 ucsaic2f.
         UCSAIC31 ucsaic3f. UCSTED7 ucsted7f. UCSTED16 ucsted1f.
         UCSTED17 ucsted0f. UCSTED31 ucsted3f. CSTPRCL cstprcl.
         AVGAFT avgaft. AVGCNET avgcnet. AVGCH avgch.
         AVGCLED avgcled. AVGTRAN avgtran. AVGHIV avghiv.
         AVGHM avghm. AVGHOUS avghous. AVGIASS avgiass.
         AVGMDS avgmds. AVGMES avgmes. AVGMHGC avgmhgc.
         AVGMHIC avgmhic. AVGPEVL avgpevl. AVGPSE avgpse.
         AVGRMGT avgrmgt. AVGSAGC avgsagc. AVGSAIC avgsaic.
         AVGSTED avgsted.  ;

RUN ;
